LIDA | Demo
Description: LIDA is a tool to automatically explore data, generate visualizations and infographics from data using large language models like ChatGPT and GPT4

Lida provides a conversational interface for automatic generation of grammar-agnostic visualizations (and infographics) from data!.
Select a visualization library/grammar
Seaborn
Model: gpt-3.5-turbo-0301, n: 1, number of Temperature: 0 ...
Ready? Upload a file to begin.

Click or drag file to this area to upload

Upload .json or .csv files to generate a visualization.

Don't have data? Try any of the files below
stocks.csv
cars.json
wheat.json
movies.json
seattle-weather.csv
sp500.csv
la-riots.csv
airports.csv
Made at Microsoft Research. Privacy & Cookies